pub struct InspectResultEntry {
pub semantic_path: String,
pub status: String,
pub source: Option<String>,
pub start_line: Option<usize>,
pub end_line: Option<usize>,
pub language: Option<String>,
pub dependencies: Option<Vec<DeepContextDependency>>,
pub error: Option<String>,
}Expand description
Result entry for a single inspect operation in a batch.
Fields
semantic_path: Stringstatus: Stringsource: Option<String>start_line: Option<usize>end_line: Option<usize>language: Option<String>dependencies: Option<Vec<DeepContextDependency>>error: Option<String>Trait Implementations
Sourceimpl Clone for InspectResultEntry
impl Clone for InspectResultEntry
Sourcefn clone(&self) -> InspectResultEntry
fn clone(&self) -> InspectResultEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InspectResultEntry
impl Debug for InspectResultEntry
Sourceimpl<'de> Deserialize<'de> for InspectResultEntry
impl<'de> Deserialize<'de> for InspectResultEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for InspectResultEntry
impl JsonSchema for InspectResultEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for InspectResultEntry
impl RefUnwindSafe for InspectResultEntry
impl Send for InspectResultEntry
impl Sync for InspectResultEntry
impl Unpin for InspectResultEntry
impl UnsafeUnpin for InspectResultEntry
impl UnwindSafe for InspectResultEntry