ReadSourceFileMetadata

Struct ReadSourceFileMetadata 

pub struct ReadSourceFileMetadata {
    pub language: String,
    pub content: Option<String>,
    pub symbols: Vec<SourceSymbol>,
    pub duration_ms: Option<u64>,
    pub unsupported_language: Option<bool>,
}
The metadata embedded in structured_content for read_source_file.

Fields

language: String

Programming language of the source file.

content: Option<String>

Clean source content without timing metadata appended. Provided so consumers like read_files get uncontaminated content.

symbols: Vec<SourceSymbol>

Symbols extracted from the source file.

duration_ms: Option<u64>

Wall-clock time in milliseconds that this tool call took to complete.

unsupported_language: Option<bool>

Whether this file’s language is not supported for AST parsing. When true, content is raw file content and symbols is empty.