pub struct ReadSymbolScopeResponse {
pub content: String,
pub start_line: usize,
pub end_line: usize,
pub version_hash: String,
pub language: String,
}Expand description
The response for read_symbol_scope.
Fields
content: StringThe extracted symbol source code.
start_line: usizeStarting line number of the symbol in the source.
end_line: usizeEnding line number of the symbol in the source.
version_hash: StringVersion hash of the file containing the symbol.
language: StringProgramming language of the source symbol.