pub struct SourceSymbol {
pub name: String,
pub semantic_path: String,
pub kind: String,
pub start_line: usize,
pub end_line: usize,
pub children: Vec<Self>,
}Expand description
A symbol output for read_source_file.
Fields
name: StringName of the symbol.
semantic_path: StringSemantic path of the symbol.
kind: StringKind of the symbol (e.g., function, struct).
start_line: usizeStarting line number of the symbol in the source.
end_line: usizeEnding line number of the symbol in the source.
children: Vec<Self>Child symbols nested within this symbol.