pub struct SymbolOverviewImpactEntry {
pub semantic_path: String,
pub file: String,
pub line: usize,
pub snippet: String,
pub direction: String,
}Expand description
A single entry in the impact summary.
Fields
semantic_path: Stringfile: Stringline: usizesnippet: Stringdirection: StringTrait Implementations
Sourceimpl Clone for SymbolOverviewImpactEntry
impl Clone for SymbolOverviewImpactEntry
Sourcefn clone(&self) -> SymbolOverviewImpactEntry
fn clone(&self) -> SymbolOverviewImpactEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SymbolOverviewImpactEntry
impl Debug for SymbolOverviewImpactEntry
Sourceimpl<'de> Deserialize<'de> for SymbolOverviewImpactEntry
impl<'de> Deserialize<'de> for SymbolOverviewImpactEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SymbolOverviewImpactEntry
impl JsonSchema for SymbolOverviewImpactEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SymbolOverviewImpactEntry
impl RefUnwindSafe for SymbolOverviewImpactEntry
impl Send for SymbolOverviewImpactEntry
impl Sync for SymbolOverviewImpactEntry
impl Unpin for SymbolOverviewImpactEntry
impl UnsafeUnpin for SymbolOverviewImpactEntry
impl UnwindSafe for SymbolOverviewImpactEntry