pub struct SymbolOverviewReference {
pub file: String,
pub line: u32,
pub column: u32,
pub snippet: String,
}Expand description
A reference location in symbol_overview.
Fields
file: Stringline: u32column: u32snippet: StringTrait Implementations
Sourceimpl Clone for SymbolOverviewReference
impl Clone for SymbolOverviewReference
Sourcefn clone(&self) -> SymbolOverviewReference
fn clone(&self) -> SymbolOverviewReference
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SymbolOverviewReference
impl Debug for SymbolOverviewReference
Sourceimpl<'de> Deserialize<'de> for SymbolOverviewReference
impl<'de> Deserialize<'de> for SymbolOverviewReference
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SymbolOverviewReference
impl JsonSchema for SymbolOverviewReference
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SymbolOverviewReference
impl RefUnwindSafe for SymbolOverviewReference
impl Send for SymbolOverviewReference
impl Sync for SymbolOverviewReference
impl Unpin for SymbolOverviewReference
impl UnsafeUnpin for SymbolOverviewReference
impl UnwindSafe for SymbolOverviewReference